@@ -30,8 +30,9 @@ from unicodedata import normalize
 from pathlib import Path
 import re
 import aiofiles
+import argh
 
-version = "0.0.42"
+version = "0.0.43"
 
 AUTH_DB_PATH = "{}/auth.db".format(CONFIG["CIRCE_WORKING_DIR"])
 
@@ -461,10 +462,13 @@ def remove_api_access(app_uuid: str):
         conn.commit()
 
 
+@argh.arg('--app_uuid', help='specify app uuid to change existing access. Ignore to create new access.')
+@argh.arg('--title', help="Title of access (name of app).")
+@argh.arg("--out", help="output credentials in json format to given file")
 def make_api_access(
-    app_uuid: "specify app uuid to change existing access. Ignore to create new access." = None,
-    title: "Title of access (name of app)." = None,
-    out: "output credentials in json format to given file" = None,
+    app_uuid: str = None,
+    title: str = None,
+    out: str = None,
 ):
     """
     Create new app uuid / secret couple for api access.
